from datetime import datetime
from typing import TYPE_CHECKING
from uuid import UUID

from sqlalchemy import ForeignKey, func
from sqlalchemy.orm import Mapped, mapped_column, relationship

from src.core.database import Base

if TYPE_CHECKING:
    from src.core.database import User, TgChat


class Success(Base):
    __tablename__ = 'successed'
    id: Mapped[int] = mapped_column(
        primary_key=True,
        autoincrement=True,
        unique=True,
    )
    user_id: Mapped[str] = mapped_column(
        ForeignKey('users.id', ondelete='CASCADE'),
    )
    slice_id: Mapped[UUID] = mapped_column(
        ForeignKey('tgchats.slice_id', ondelete='CASCADE'),
    )
    reason: Mapped[str]
    created_at: Mapped[datetime] = mapped_column(
        default=datetime.utcnow,
        server_default=func.now()
    )

    user_relationship: Mapped["User"] = relationship(
        backref="success_relationship"
    )
    chat_relationship: Mapped["TgChat"] = relationship(
        backref="success_relationship"
    )