from uuid import UUID

from sqlalchemy import insert, select
from sqlalchemy.orm import selectinload, joinedload
from sqlalchemy.ext.asyncio import AsyncSession

from src.core.database import TgMessage, TgChat
from src.core.workers.schemas import ResponseFromGeminiSchema
from src.core.database.successes import Success


async def bulk_create_success_reasons(
        session: AsyncSession,
        success_schema: ResponseFromGeminiSchema,
) -> None:
    stmt = (
        insert(
            Success
        )
        .values(
            [chat.model_dump for chat in success_schema.success]
        )
    )
    await session.execute(stmt)
    await session.commit()


async def get_messages_by_slice_id(
        session: AsyncSession,
        slice_id: UUID
) -> Success:
    stmt = (
        select(Success)
        .options(
            joinedload(Success.user_relationship),
            joinedload(Success.chat_relationship)
            .selectinload(TgChat.message_relationship)
        )
        .where(Success.slice_id == slice_id)
    )
    return await session.scalar(stmt)


