from typing import Annotated

from sqlalchemy.ext.asyncio import AsyncSession

from faststream import Depends

from src.core.tg_service.service import notify_for_success
from src.core.workers.schemas import ResponseFromGeminiSchema
from src.core.database.connect import db_helper
from src.core.rabbitmq.connect import success_gemini_subscriber
from src.core.workers import crud as workers_crud


@success_gemini_subscriber
async def create_success_record(
        message: ResponseFromGeminiSchema,
        session: Annotated[AsyncSession, Depends(db_helper.get_async_session)],
):
    await workers_crud.bulk_create_success_reasons(
        success_schema=message,
        session=session,
    )

    for success_message in message.success:
        success_mod_with_relation = await workers_crud.get_messages_by_slice_id(
            session=session,
            slice_id=success_message.slice_id,
        )

        await notify_for_success(
            messages=success_mod_with_relation.chat_relationship.message_relationship,
            chat=success_mod_with_relation.chat_relationship,
            user_model=success_mod_with_relation.user_relationship,
            success_reason=success_mod_with_relation,,
        )






